@@ -154,12 +154,18 @@ void init_playlist()
 	pl.size = 0;
 	pl.fill = 0;
 	pl.pos = 0;
+	if(APPFLAG(MPG123APP_CONTINUE) && param.listentry > 0)
+	pl.pos = param.listentry - 1;
+
 	pl.list = NULL;
 	pl.alloc_step = 10;
 	mpg123_init_string(&pl.dir);
 	mpg123_init_string(&pl.linebuf);
 	pl.type = UNKNOWN;
 	pl.loop = param.loop;
+#ifdef WANT_WIN32_SOCKETS
+	pl.sockd = -1;
+#endif
 }
 
 /*
@@ -198,7 +204,11 @@ int add_next_file (int argc, char *argv[])
 	if (param.listname || pl.file)
 	{
 		size_t line_offset = 0;
+#ifndef WANT_WIN32_SOCKETS
 		if (!pl.file)
+#else
+		if (!pl.file && pl.sockd == -1)
+#endif
 		{
 			/* empty or "-" */
 			if (!*param.listname || !strcmp(param.listname, "-"))
@@ -212,9 +222,13 @@ int add_next_file (int argc, char *argv[])
 				int fd;
 				struct httpdata htd;
 				httpdata_init(&htd);
+#ifndef WANT_WIN32_SOCKETS
 				fd = http_open(param.listname, &htd);
+#else
+				fd = win32_net_http_open(param.listname, &htd);
+#endif
 				debug1("htd.content_type.p: %p", (void*) htd.content_type.p);
-				if(!param.ignore_mime && htd.content_type.p != NULL)
+				if(!APPFLAG(MPG123APP_IGNORE_MIME) && htd.content_type.p != NULL)
 				{
 					int mimi;
 					debug1("htd.content_type.p value: %s", htd.content_type.p);
@@ -224,9 +238,13 @@ int add_next_file (int argc, char *argv[])
 					else if(mimi & IS_PLS)	pl.type = PLS;
 					else
 					{
+#ifndef WANT_WIN32_SOCKETS
 						if(fd >= 0) close(fd);
-
+#else
+						if(fd != SOCKET_ERROR) win32_net_close(fd);
+#endif
 						fd = -1;
+						
 						if(mimi & IS_FILE)
 						{
 							pl.type = NO_LIST;
@@ -250,12 +268,19 @@ int add_next_file (int argc, char *argv[])
 				{
 					param.listname = NULL;
 					pl.file = NULL;
+#ifdef WANT_WIN32_SOCKETS
+					pl.sockd = -1;
+#endif
 					error("Invalid playlist from http_open()!\n");
 				}
 				else
 				{
 					pl.entry = 0;
+#ifndef WANT_WIN32_SOCKETS
 					pl.file = fdopen(fd,"r");
+#else
+					pl.sockd = fd;
+#endif
 				}
 			}
 			else if (!(pl.file = fopen(param.listname, "rb")))
@@ -272,7 +297,11 @@ int add_next_file (int argc, char *argv[])
 			firstline = 1; /* just opened */
 		}
 		/* reading the file line by line */
+#ifndef WANT_WIN32_SOCKETS
 		while (pl.file)
+#else
+		while (pl.file || (pl.sockd) != -1)
+#endif
 		{
 			/*
 				now read a string of arbitrary size...
@@ -293,7 +322,11 @@ int add_next_file (int argc, char *argv[])
 					}
 				}
 				/* I rely on fgets writing the \0 at the end! */
+#ifndef WANT_WIN32_SOCKETS
 				if(fgets(pl.linebuf.p+have, pl.linebuf.size-have, pl.file))
+#else
+				if( (pl.file ? (fgets(pl.linebuf.p+have, pl.linebuf.size-have, pl.file)) : (win32_net_fgets(pl.linebuf.p+have, pl.linebuf.size-have, pl.sockd))))
+#endif
 				{
 					have += strlen(pl.linebuf.p+have);
 					debug2("have read %lu characters into linebuf: [%s]", (unsigned long)have, pl.linebuf.p);
@@ -434,7 +467,7 @@ int add_next_file (int argc, char *argv[])
 				}
 				++pl.entry;
 				if(param.listentry < 0) printf("#entry %lu\n%s\n", (unsigned long)pl.entry,pl.linebuf.p+line_offset);
-				else if((param.listentry == 0) || (param.listentry == pl.entry))
+				else if((param.listentry == 0) || (param.listentry == pl.entry) || APPFLAG(MPG123APP_CONTINUE))
 				{
 					add_copy_to_playlist(pl.linebuf.p+line_offset);
 					return 1;
@@ -443,9 +476,16 @@ int add_next_file (int argc, char *argv[])
 			else
 			{
 				if (param.listname)
-				fclose (pl.file);
+				if(pl.file) fclose (pl.file);
 				param.listname = NULL;
 				pl.file = NULL;
+#ifdef WANT_WIN32_SOCKETS
+				if( pl.sockd != -1)
+				{
+				  win32_net_close(pl.sockd);
+				  pl.sockd = -1;
+				}
+#endif
 			}
 		}
 	}
